bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaARD.set_plotter
=======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaARD.set_plotter